require("assets")
require("state_manager")

local push = require("libs.push")
sti = require("libs.sti")

-- States
require("states.Game")

local gameWidth, gameHeight = 2048, 1152 -- Fixed game resolution
local windowWidth, windowHeight = love.window.getDesktopDimensions() -- Gets desktop width & height

push:setupScreen(gameWidth, gameHeight, windowWidth, windowHeight, {borderless=true}) -- Sets up push's screen

function love.load()
    Instance = {} -- Creates instance of game
    state.switch(Game) -- Loads the default/starting state
end

function love.update(dt)
    if currentState then
        state.call('update', dt) -- Calls the update function of the current state
    end
end

function love.draw()
    push:start() -- Starts the push
    if currentState then
        state.call('draw') -- Calls the draw function of the current state
    end
    push:finish() -- Ends the push
end

function love.keypressed(key)
    if currentState then
        state.call('keypressed', { key = key }) -- Calls the keypressed function of the current state
    end
end

function love.keyreleased(key)
    if currentState then
        state.call('keyreleased', { key = key }) -- Calls the keyreleased function of the current state
    end
end

function love.mousepressed(x, y, button)
    if currentState then
        state.call('mousepressed', { x = x, y = y }) -- Calls the mousepressed function of the current state
    end
end

function love.mousereleased(x, y, button)
    if currentState then
        state.call('mousereleased', { x = x, y = y }) -- Calls the mousereleased function of the current state
    end
end
